@@ -1,9 +1,10 @@
 # Test support for different classes of models
 
 require(MuMIn)
-.checkPkg <- function(package) length(find.package(package, quiet=TRUE)) != 0
+.checkPkg <- function(package) length(.find.package(package, quiet=TRUE)) != 0
 
 # TEST gls --------------------------------------------------------------------------------
+if(.checkPkg("nlme")) {
 library(nlme)
 data(Ovary, package = "nlme")
 fm1 <- gls(follicles ~ sin(2*pi*Time) + cos(2*pi*Time), Ovary,
@@ -12,6 +13,9 @@ dd <- dredge(fm1, trace=T)
 gm <- get.models(dd, 1:4)
 ma <- model.avg(gm, revised=T)
 
+dd
+mod.sel(gm)
+
 summary(ma)
 confint(ma)
 
@@ -21,6 +25,7 @@ predict(ma)
 predict(ma, data.frame(Mare=1, Time=range(Ovary$Time)))
 
 detach(package:nlme); rm(list=ls())
+}
 
 #dredge(fm1, rank=BIC)
 #dredge(fm1, rank=AIC)
@@ -31,15 +36,36 @@ d.AD <- data.frame(counts =c(18,17,15,20,10,20,25,13,12), outcome = gl(3,1,9),
 treatment = gl(3,3))
 glm.qD93 <- glm(counts ~ outcome + treatment, family=quasipoisson(), data=d.AD)
 glm.D93 <- glm(counts ~ outcome + treatment, family=poisson(), data=d.AD)
+
 dd <- dredge(glm.qD93)
 summary(model.avg(dd, subset= delta <= 10))
 dd <- dredge(glm.D93)
 summary(model.avg(dd, subset= delta <= 10))
 
+subset(dd, delta <= 10)
+mod.sel(get.models(dd, subset=delta <= 10))
+
+
+rm(list=ls())
+
+# TEST glmmML --------------------------------------------------------------------
+
+if(.checkPkg("glmmML")) {
+
+library(glmmML)
+dat <- data.frame(y = rbinom(100, prob = rep(runif(20), rep(5, 20)), size = 1),
+	x = rnorm(100), x2 = rnorm(100), id = factor(rep(1:20, rep(5, 20))))
+
+fm1 <- glmmML(y ~ x*x2, data = dat, cluster = id)
+summary(model.avg(dredge(fm1), subset = delta <= 4))
+
+detach(package:glmmML); rm(list=ls())
+
+}
 
 # TEST nlme --------------------------------------------------------------------
+if(.checkPkg("nlme")) {
 library(nlme)
-#library(lme4)
 data(Orthodont, package = "nlme")
 
 #:: Model-averaging mixed models :::::::::::::::::::::::::::::::::::::::::::::::
@@ -55,6 +81,8 @@ dd <- dredge(fm2, trace=T, rank="AICc", REML=FALSE)
 # Get models (which are fitted by REML, like the global model)
 gm <- get.models(dd, 1:4)
 
+#mod.sel(gm)
+
 ##::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 #maML <- model.avg(gm, method = "NA", rank="AICc", rank.args = list(REML=FALSE))
 #maREML <- model.avg(gm, method = "NA", rank="AICc", rank.args = list(REML=TRUE))
@@ -72,8 +100,10 @@ confint(ma0)
 predict(ma0, data.frame(Sex="Male", Subject="M01", age=8:12))
 
 detach(package:nlme); rm(list=ls())
+}
 
 # TEST lmer -------------------------------------------------------------------------------
+if(.checkPkg("lme4")) {
 
 library(lme4)
 data(Orthodont, package = "nlme")
@@ -84,6 +114,7 @@ dd <- dredge(fm2, trace=T)
 gm <- get.models(dd, 1:4)
 (ma <- model.avg(gm))
 
+
 #predict(ma)
 #predict(ma, data.frame(Sex="Male", Subject="M01", age=8:12))
 
@@ -96,8 +127,10 @@ dd <- dredge(update(fm2, REML=FALSE), trace=T)
 dd <- dredge(update(fm2, REML=F, model=F), trace=T)
 
 detach(package:lme4); rm(list=ls())
+}
 
 # TEST lm ---------------------------------------------------------------------------------
+if(.checkPkg("nlme")) {
 data(Orthodont, package = "nlme")
 
 fm1 <- lm(distance ~ Sex*age + age*Sex, data = Orthodont)
@@ -110,10 +143,11 @@ summary(ma)
 confint(ma)
 
 predict(ma)
-predict(ma, se=T)
+predict(ma, se.fit=TRUE)
 predict(ma, data.frame(Sex="Male", age=8:12))
 
 rm(list=ls())
+}
 
 # TEST glm --------------------------------------------------------------------------------
 data(Cement, package = "MuMIn")
@@ -141,6 +175,8 @@ predict(ma, lapply(Cement, nseq))
 
 rm(list=ls())
 # TEST rlm --------------------------------------------------------------------------------
+
+if (.checkPkg("MASS")) {
 library(MASS)
 data(Cement, package = "MuMIn")
 
@@ -157,6 +193,7 @@ predict(ma, lapply(Cement, nseq, len=30), se.fit=TRUE)
 rm(list=ls()); detach(package:MASS)
 
 # TEST multinom --------------------------------------------------------------------------------
+if (.checkPkg("nnet")) {
 library(nnet); library(MASS)
 
 # Trimmed-down model from example(birthwt)
@@ -179,8 +216,12 @@ summary(ma)
 # predict(ma) // Cannot average factors!
 
 rm(list=ls()); detach(package:nnet)
+}}
+
 
 # TEST gam --------------------------------------------------------------------------------
+if (.checkPkg("mgcv")) {
+
 suppressPackageStartupMessages(library(mgcv))
 RNGkind("Mersenne")
 set.seed(0) ## simulate some data...
@@ -191,15 +232,17 @@ ops <- options(warn = -1)
 
 gam1 <- gam(y ~ s(x0) + s(x1) + s(x2) +  s(x3) + (x1+x2+x3)^2,
 	data = dat, method = "ML")
+
 dd <- dredge(gam1, subset=!`s(x0)` & (!`s(x1)` | !x1) & (!`s(x2)` | !x2) & (!`s(x3)` | !x3), fixed="x1", trace=T)
+
 gm <- get.models(dd, cumsum(weight) <= .95)
 ma <- model.avg(gm)
 
-predict(ma, se.fit=T)
+predict(ma, dat[1:10, ], se.fit=T)
 options(ops)
 
-
 rm(list=ls()); detach(package:mgcv)
+}
 
 # TEST spautolm ---------------------------------------------------------------------------
 
@@ -241,12 +284,14 @@ rm(list=ls()); detach(package:spdep)
 
 
 # TEST glm.nb ---------------------------------------------------------------------------
+if (.checkPkg("MASS")) {
 require(MASS)
 
 quine.nb1 <- glm.nb(Days ~ 0+Sex/(Age + Eth*Lrn), data = quine)
+#quine.nb1 <- glm.nb(Days ~ Sex/(Age + Eth*Lrn), data = quine)
 
 dredge(quine.nb1) # Wrong
-#dredge(quine.nb1, marg.ex="Sex") # Right
+dredge(quine.nb1, marg.ex="Sex") # Right
 ma <- model.avg(dredge(quine.nb1, marg.ex="Sex"), subset=cumsum(weight)<=.9999)
 
 pred <- predict(ma, se=TRUE)
@@ -255,6 +300,7 @@ pred <- predict(ma, se=TRUE)
 #matplot(family(quine.nb1)$linkinv(pred), type="l")
 
 rm(list=ls()); detach(package:MASS)
+}
 
 # TEST quasibinomial ---------------------------------------------------------------------------
 
@@ -279,7 +325,7 @@ ma <- model.avg(mod[1:5], rank="QAICc", rank.args = list(chat = 0.403111))
 rm(list=ls());
 
 # TEST polr {MASS} ---------------------------------------------------------------------------
-
+#if (.checkPkg("MASS")) {
 #library(MASS)
 #library(MuMIn)
 #options(contrasts = c("contr.treatment", "contr.poly"))
@@ -288,6 +334,6 @@ rm(list=ls());
 #dd <- dredge(house.plr)
 #mod <- get.models(dd, 1:6)
 #model.avg(mod)
-
+#}
 
 # END TESTS
